@@ -39,13 +39,7 @@ class UniUtil:
     @staticmethod
     def uuidd(param: dict = None):
         """字典uuid"""
-        if param is None:
-            return uuid.uuid1()
-        else:
-            p1 = sorted(param.items(), key=lambda x: x[0])
-            p2 = [str(p) for p in p1]
-            p3 = '|'.join(p2)
-            return UniUtil.uuids(p3)
+        return UniUtil.uuids(param)
 
     @staticmethod
     def uuids(param: str = None):
@@ -53,7 +47,7 @@ class UniUtil:
         if param is None:
             return uuid.uuid1()
         else:
-            return str(uuid.uuid3(uuid.NAMESPACE_OID, param))
+            return str(uuid.uuid3(uuid.NAMESPACE_OID, str(param)))
 
     @staticmethod
     def get_uuid(param: dict = None):
